<?php

/**
 * @file
 * Contains Drupal\ses_mailer\SesMailer
 */

use Aws\Exception\AwsException;
use Aws\Sdk;

/**
 * AWS SES mailer implementation.
 */
class SesMailer implements MailSystemInterface {

  /**
   * {@inheritdoc}
   */
  public function format(array $message) {
    // Join the body array into one string.
    $message['body'] = implode("\n\n", $message['body']);
    // Convert any HTML to plain-text.
    $message['body'] = drupal_html_to_text($message['body']);
    // Wrap the mail body for sending.
    $message['body'] = drupal_wrap_mail($message['body']);
    return $message;
  }

  /**
   * {@inheritdoc}
   */
  public function mail(array $message) {
    $result['error'] = FALSE;
    $settings = [
      'region' => variable_get('ses_mailer_region', 'us-east-1'),
      'version' => 'latest',
    ];
    $profile = variable_get('ses_mailer_profile');
    if (isset($profile)) {
      $settings['profile'] = $profile;
    }
    $sdk = new Sdk($settings);

    try {
      // Credentials are set in environment variables.
      $client = $sdk->createSes();
      $headers = $message['headers'];
      $client->sendEmail([
          'Destination' => [
            'ToAddresses' => [$message['to']],
          ],
          'Message' => [
            'Body' => [
              'Text' => [
                'Data' => $message['body'],
              ],
            ],
            'Subject' => [
              'Data' => $message['subject'],
            ],
          ],
          'ReplyToAddresses' => [$headers['From']],
          'ReturnPath' => $headers['Return-Path'],
          'Source' => $headers['Sender'],
        ]
      );
      watchdog('ses_mailer', 'Successfully sent email to %to', ['%to' => $message['to']]);
    }
    catch (AwsException $e) {
      watchdog_exception('ses_mailer', $e);
      $result['message'] = $e->getAwsErrorType();
      $result['errorCode'] = $e->getAwsErrorCode();
      $result['error'] = TRUE;
    }
    return $result;
  }

}
